=============================
Django Awards
=============================

.. image:: https://badge.fury.io/py/django-awards.png
    :target: https://badge.fury.io/py/django-awards

.. image:: https://travis-ci.org/fgmacedo/django-awards.png?branch=master
    :target: https://travis-ci.org/fgmacedo/django-awards

A Django Badge Awards application.

Documentation
-------------

The full documentation is at https://django-awards.readthedocs.org.

Quickstart
----------

Install Django Awards::

    pip install django-awards

Then use it in a project::

    import awards

Add a `badges.py` file into the app that you want to define badges to.



Features
--------

* TODO

Running Tests
--------------

Does the code actually work?

::

    source <YOURVIRTUALENV>/bin/activate
    (myenv) $ pip install -r requirements_test.txt
    (myenv) $ py.test
